<?php
/**
 * Plugin Name: Dadevarzan WordPress catalog plugin
 * Plugin URI: https://wordpress.org/plugins/dadevarzan-wp-catalog
 * GitHub Plugin URI: https://github.com/dadevarzan/dadevarzan-wp-catalog
 * Description: catalog post type for wordpress
 * Version: 1.1.8
 * Author: Dadevarzan Team
 * Author URI: http://www.dadevarzan.com
 * Text Domain: dadevarzan-wp-catalog
 * Domain Path: /languages
*/

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
    die;
}

if ( !class_exists( 'dadevarzanWpCatalog' ) ) {

    class dadevarzanWpCatalog
    {

        public static function initialize()
        {
            add_action( 'plugins_loaded', 'dadevarzanWpCatalog::load_text_domain' );
            add_action( 'init', 'dadevarzanWpCatalog::add_post_type' );
            add_action( 'init', 'dadevarzanWpCatalog::add_fields' );
            add_action('init', 'dadevarzanWpCatalog::add_taxonomy');
            add_action('init', 'dadevarzanWpCatalog::add_role_caps');
            add_action( 'plugins_loaded', 'dadevarzanWpCatalog::load_templates' );

        }

        public static function add_post_type()
        {

            $labels = array(
                "name" => __('Catalogs', 'dadevarzan-wp-catalog'),
                "singular_name" => __('Catalog', 'dadevarzan-wp-catalog'),
                "all_items" => __('All Catalogs', 'dadevarzan-wp-catalog'),
                "add_new" => __('Add Catalog', 'dadevarzan-wp-catalog'),
                "add_new_item" => __('Add New Catalog', 'dadevarzan-wp-catalog'),
                "edit_item" => __('Edit Catalog', 'dadevarzan-wp-catalog'),
                "new_item" => __('New Catalog', 'dadevarzan-wp-catalog'),
                "view_item" => __('View Catalog', 'dadevarzan-wp-catalog'),
            );

            $args = array(
                "label" => __('Catalogs', 'dadevarzan-wp-catalog'),
                "labels" => $labels,
                "description" => "",
                "public" => true,
                "publicly_queryable" => true,
                "show_ui" => true,
                "show_in_rest" => true,
                "rest_base" => "",
				"show_in_nav_menus" => true,
                "has_archive" => true,
                "show_in_menu" => true,
                "exclude_from_search" => false,
                "hierarchical" => false,
                "rewrite" => array( "slug" => "catalog", "with_front" => true ),
                "query_var" => true,
                "menu_icon" => "dashicons-layout",
                "supports" => array( "title", "excerpt", "editor", "thumbnail", "comments", "author" ),
                "capability_type" => array('catalog', 'catalogs'),
                "map_meta_cap" => true,
                "taxonomies" => array( "catalog_category" ),
            );

            register_post_type( "catalog", $args );

        }

        public static function add_fields()
        {

            if( function_exists('acf_add_local_field_group') ):

                acf_add_local_field_group(array(
                    'key' => 'group_5a0805fca3f98',
                    'title' => __('Catalogs', 'dadevarzan-wp-catalog'),
                    'fields' => array(
                        array(
                            'key' => 'field_5a080634daada',
                            'label' => __('Catalog file', 'dadevarzan-wp-catalog'),
                            'name' => 'ctlg_file',
                            'type' => 'file',
                            'instructions' => __('Allowed extensions are pdf and zip', 'dadevarzan-wp-catalog'),
                            'required' => 1,
                            'conditional_logic' => 0,
                            'wrapper' => array(
                                'width' => '',
                                'class' => '',
                                'id' => '',
                            ),
                            'return_format' => 'array',
                            'library' => 'all',
                            'min_size' => '',
                            'max_size' => '',
                            'mime_types' => 'pdf,zip',
                        ),
                    ),
                    'location' => array(
                        array(
                            array(
                                'param' => 'post_type',
                                'operator' => '==',
                                'value' => 'catalog',
                            ),
                        ),
                    ),
                    'menu_order' => 0,
                    'position' => 'acf_after_title',
                    'style' => 'default',
                    'label_placement' => 'top',
                    'instruction_placement' => 'label',
                    'hide_on_screen' => '',
                    'active' => 1,
                    'description' => '',
                ));

            endif;

        }

        public static function add_taxonomy()
        {

            $labels = array(
                "name" => __('Catalog Categories', 'dadevarzan-wp-catalog'),
                "singular_name" => __('Catalog Category', 'dadevarzan-wp-catalog'),
            );

            $args = array(
                "label" => __('Catalog Categories', 'dadevarzan-wp-catalog'),
                "labels" => $labels,
                "public" => true,
                "hierarchical" => true,
                "show_ui" => true,
                "show_in_menu" => true,
                "show_in_nav_menus" => true,
                "query_var" => true,
                "rewrite" => array( 'slug' => 'catalog_category', 'with_front' => true, ),
                "show_admin_column" => true,
                "show_in_rest" => true,
                "rest_base" => "",
                "show_in_quick_edit" => true,
                'capabilities' => array(
                    'manage_terms' => 'manage_categories',
                    'edit_terms' => 'manage_categories',
                    'delete_terms' => 'manage_categories',
                    'assign_term' => 'manage_categories',
                    'assign_terms' => 'manage_categories',
                ),
            );

            register_taxonomy( 'catalog_category', array( 'catalog' ), $args );

        }

        public static function add_role_caps()
        {

            // Add the roles you'd like to administer the custom post types
            $roles = array('wpseo_editor', 'wpseo_manager', 'shop_manager', 'editor', 'administrator');

            // Loop through each role and assign capabilities
            foreach($roles as $the_role) {

                $role = get_role($the_role);

                if ( empty($role) ) {
                    continue;
                }

                $role->add_cap( 'read' );
                $role->add_cap( 'read_catalog' );
                $role->add_cap( 'edit_catalog' );
                $role->add_cap( 'edit_catalogs' );
                $role->add_cap( 'edit_private_catalogs' );
                $role->add_cap( 'edit_published_catalogs' );
                $role->add_cap( 'edit_others_catalogs' );
                $role->add_cap( 'delete_catalog' );
                $role->add_cap( 'delete_catalogs' );
                $role->add_cap( 'delete_private_catalogs' );
                $role->add_cap( 'delete_published_catalogs' );
                $role->add_cap( 'delete_others_catalogs' );
                $role->add_cap( 'publish_catalogs' );
                $role->add_cap( 'read_private_catalogs' );

            }

        }

        public static function load_templates() {

            /**
             * Return if the builder isn't installed or if the current
             * version doesn't support registering templates.
             */
            if ( ! class_exists( 'FLBuilder' ) || ! method_exists( 'FLBuilder', 'register_templates' ) ) {
                return;
            }

            $layoutTemplatePath = plugin_dir_path( __FILE__ ) . 'data/templates.dat';
            if ( file_exists( $layoutTemplatePath ) && class_exists( 'FLThemeBuilder' ) ) {
                FLBuilder::register_templates( $layoutTemplatePath, array('group' => 'catalog'));
            }

        }

        public static function load_text_domain()
        {
            load_plugin_textdomain( 'dadevarzan-wp-catalog' , FALSE, basename( dirname( __FILE__ ) ) . '/languages'  );
        }

    }

    dadevarzanWpCatalog::initialize();

}
